@@ -27,11 +27,7 @@ describe 'panko::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-pankoclient' }
-          else
-            { :client_package_name => 'python-pankoclient' }
-          end
+          { :client_package_name => 'python3-pankoclient' }
         when 'RedHat'
           { :client_package_name => 'python-pankoclient' }
         end
